@@ -1,5 +1,5 @@
 /*
- * $Id: main.cpp,v 1.31 2008/08/07 18:25:41 tyreld Exp $
+ * $Id: main.cpp,v 1.34 2009/06/24 17:44:48 tyreld Exp $
  *
  * main.cpp
  *
@@ -68,7 +68,7 @@ static void usage(int indir, int op, char *cmd)
 {
    cerr<<"usage:";
    cerr<<"\twbemcli gc|gcd|dc|ec|ecn|gi|ci|mi|di|ei|ein|ain|ai|rin|ri|gp|sp|cm|cmx\n"
-         "\t        [-nl] [-dx] [-t] [-h] [-v]\n"
+         "\t        [-nl] [-dx] [-t] [-cte] [-h] [-v]\n"
          "\t        [-noverify] [-cacert <file>] [-clientcert <file>] [-clientkey <file>]\n"
          "\t        [-ac <assocClass>] [-arc <resultClass>] [-ar <role>] [-arr <resultRole>]\n"
          "\t        objectPath [prop=value,[...]] [props[,...]]\n"<<endl;
@@ -119,7 +119,7 @@ int main (int argc, char *argv[]) {
    int pos, retval = 0;
    char *cmd, *params, *opStr=NULL,*urlStr=NULL,*xtraStr=NULL;
    char *assocClass=NULL,*resultClass=NULL,*role=NULL,*resultRole=NULL;
-   char *cacert=CACERT, *clientcert=NULL, *clientkey=NULL;
+   const char *cacert=CACERT, *clientcert=NULL, *clientkey=NULL;
    int n=1,err=0,op=0,cmdln,help=0,indir=0, noverify=0;
    ClassXml *cls=0;
    InstanceXml *inst=0;
@@ -201,7 +201,8 @@ int main (int argc, char *argv[]) {
  	   else if (strcmp(*argv,"-ar")==0) role=*(++argv);
  	   else if (strcmp(*argv,"-arr")==0) resultRole=*(++argv);
            else if (strcmp(*argv,"-v")==0) {
-              cerr<<"* wbemcli Version " PACKAGE_VERSION ", $Date: 2008/08/07 18:25:41 $" <<endl;
+              cerr<<"* wbemcli Version " PACKAGE_VERSION ", $Date: 2009/06/24 17:44:48 $" <<endl;
+              goto fini;
            }
            else err=1;
          }
@@ -295,7 +296,7 @@ int main (int argc, char *argv[]) {
 	 if (ASSOC_PARMS)
            throw CmdException("Invalid command invocation");
          if ((inst=cimom.getInstance(url,xtraStr))) {
-            url.toStringBuffer(sb,0);
+            url.toStringBufferGI(sb);
             if (useNl) sb += "\n";
             else sb += " ";
 	    inst->propagateKeyFlags(url.keys);
